summaryrefslogtreecommitdiff
path: root/src/lib/openjp2/t1.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/openjp2/t1.h')
-rw-r--r--src/lib/openjp2/t1.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/lib/openjp2/t1.h b/src/lib/openjp2/t1.h
index da8b0c80..5aa6a07b 100644
--- a/src/lib/openjp2/t1.h
+++ b/src/lib/openjp2/t1.h
@@ -202,10 +202,12 @@ typedef struct opj_t1 {
OPJ_BOOL encoder;
/* Thre 3 variables below are only used by the decoder */
- OPJ_BOOL mustuse_segdatabuffer; /* set to TRUE in multithreaded context */
- OPJ_BYTE
- *segdatabuffer; /* Temporary buffer to concatenate all chunks of a segment */
- OPJ_UINT32 segdatabuffersize; /* Maximum size available in segdatabuffer */
+ /* set to TRUE in multithreaded context */
+ OPJ_BOOL mustuse_cblkdatabuffer;
+ /* Temporary buffer to concatenate all chunks of a codebock */
+ OPJ_BYTE *cblkdatabuffer;
+ /* Maximum size available in cblkdatabuffer */
+ OPJ_UINT32 cblkdatabuffersize;
} opj_t1_t;
/** @name Exported functions */